==> mx-packageinstaller-pkglist_19.01.01.tar.xz: mx-packageinstaller-pkglist/evince.pm <==
<?xml version="1.0"?>
<app>

<category>
Office
</category>

<name>
Evince
</name>

<description>
   <am>a simple document (PostScript, PDF) viewer</am>
   <ca>senzill visor de documents (PDF, Postscript)</ca>
   <cs>a simple document (PostScript, PDF) viewer</cs>
   <da>a simple document (PostScript, PDF) viewer</da>
   <de>Ein einfacher Dokumentenbetrachter (PostScript, PDF)</de>
   <el>ένα απλό πρόγραμμα προβολής (PostScript, PDF)</el>
   <en>a simple document (PostScript, PDF) viewer</en>
   <es>Visor de documentos (PostScript, PDF) sencillo</es>
   <fi>a simple document (PostScript, PDF) viewer</fi>
   <fr>Visionneuse simple de documents (PostScript, PDF)</fr>
   <hi>a simple document (PostScript, PDF) viewer</hi>
   <hr>a simple document (PostScript, PDF) viewer</hr>
   <hu>a simple document (PostScript, PDF) viewer</hu>
   <is>a simple document (PostScript, PDF) viewer</is>
   <it>Un semplice visualizzatore di documenti (PostScript, PDF)</it>
   <ja>a simple document (PostScript, PDF) viewer</ja>
   <kk>a simple document (PostScript, PDF) viewer</kk>
   <lt>a simple document (PostScript, PDF) viewer</lt>
   <nl>een eenvoudige document (PostScript, PDF) lezer</nl>
   <pl>a simple document (PostScript, PDF) viewer</pl>
   <pt_BR>a simple document (PostScript, PDF) viewer</pt_BR>
   <pt>Visualizador de documentos (PostScript, PDF) simples e de fácil utilização</pt>
   <ro>a simple document (PostScript, PDF) viewer</ro>
   <ru>Просмотрщик документов PostScript, PDF</ru>
   <sk>a simple document (PostScript, PDF) viewer</sk>
   <sq>a simple document (PostScript, PDF) viewer</sq>
   <sv>en enkel dokument (PostScript, PDF) läsare</sv>
   <tr>a simple document (PostScript, PDF) viewer</tr>
   <uk>a simple document (PostScript, PDF) viewer</uk>
   <zh_TW>a simple document (PostScript, PDF) viewer</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/015/840/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
evince
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
evince
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.03.01.tar.xz: mx-packageinstaller-pkglist/evince.pm <==
<?xml version="1.0"?>
<app>

<category>
Office
</category>

<name>
Evince
</name>

<description>
   <am>a simple document (PostScript, PDF) viewer</am>
   <ar>a simple document (PostScript, PDF) viewer</ar>
   <bg>a simple document (PostScript, PDF) viewer</bg>
   <ca>senzill visor de documents (PDF, Postscript)</ca>
   <cs>a simple document (PostScript, PDF) viewer</cs>
   <da>en simpel dokumentfremviser (PostScript, PDF)</da>
   <de>Ein einfacher Dokumentenbetrachter (PostScript, PDF)</de>
   <el>ένα απλό πρόγραμμα προβολής (PostScript, PDF)</el>
   <en>a simple document (PostScript, PDF) viewer</en>
   <es>Visor de documentos (PostScript, PDF) sencillo</es>
   <et>a simple document (PostScript, PDF) viewer</et>
   <eu>a simple document (PostScript, PDF) viewer</eu>
   <fa>a simple document (PostScript, PDF) viewer</fa>
   <fi>a simple document (PostScript, PDF) viewer</fi>
   <fr>Visionneuse simple de documents (PostScript, PDF)</fr>
   <he_IL>a simple document (PostScript, PDF) viewer</he_IL>
   <hi>a simple document (PostScript, PDF) viewer</hi>
   <hr>a simple document (PostScript, PDF) viewer</hr>
   <hu>a simple document (PostScript, PDF) viewer</hu>
   <id>a simple document (PostScript, PDF) viewer</id>
   <is>a simple document (PostScript, PDF) viewer</is>
   <it>Un semplice visualizzatore di documenti (PostScript, PDF)</it>
   <ja_JP>a simple document (PostScript, PDF) viewer</ja_JP>
   <ja>a simple document (PostScript, PDF) viewer</ja>
   <kk>a simple document (PostScript, PDF) viewer</kk>
   <ko>a simple document (PostScript, PDF) viewer</ko>
   <lt>a simple document (PostScript, PDF) viewer</lt>
   <mk>a simple document (PostScript, PDF) viewer</mk>
   <nb>a simple document (PostScript, PDF) viewer</nb>
   <nl>een eenvoudige document (PostScript, PDF) lezer</nl>
   <pl>a simple document (PostScript, PDF) viewer</pl>
   <pt_BR>a simple document (PostScript, PDF) viewer</pt_BR>
   <pt>Visualizador de documentos (PostScript, PDF) simples e de fácil utilização</pt>
   <ro>a simple document (PostScript, PDF) viewer</ro>
   <ru>Просмотрщик документов PostScript, PDF</ru>
   <sk>a simple document (PostScript, PDF) viewer</sk>
   <sl>a simple document (PostScript, PDF) viewer</sl>
   <sq>a simple document (PostScript, PDF) viewer</sq>
   <sr>a simple document (PostScript, PDF) viewer</sr>
   <sv>en enkel dokument (PostScript, PDF) läsare</sv>
   <tr>a simple document (PostScript, PDF) viewer</tr>
   <uk>простий переглядач документів (PostScript, PDF)</uk>
   <zh_CN>a simple document (PostScript, PDF) viewer</zh_CN>
   <zh_TW>a simple document (PostScript, PDF) viewer</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/015/840/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
evince
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
evince
</uninstall_package_names>
</app>
